@@ -148,35 +148,31 @@ gps_mask_t evermore_parse(struct gps_device_t * session, unsigned char *buf,
     double version;
     gps_mask_t mask = 0;
 
-    if (len == 0)
+    /* must have two leader bytes, length, and two trailer bytes minimum */
+    if (len < 5)
 	return 0;
 
     /* time to unstuff it and discard the header and footer */
     cp = buf + 2;
-    tp = buf2;
     if (*cp == 0x10)
 	cp++;
     datalen = (size_t) * cp++;
-
-    gpsd_report(LOG_RAW, "raw EverMore packet type 0x%02x, length %zd: %s\n",
-		*cp, len, gpsd_hexdump_wrapper(buf, len, LOG_RAW));
-
     datalen -= 2;
 
     /*@ -usedef @*/
+    buf2[0] = '\0';	/* prevent 'Assigned value is garbage or undefined' from scan-build */
+    tp = buf2;
     for (i = 0; i < (size_t) datalen; i++) {
 	*tp = *cp++;
 	if (*tp == 0x10)
 	    cp++;
 	tp++;
     }
-
     type = (unsigned char)getub(buf2, 1);
     /*@ +usedef @*/
 
     /*@ -usedef -compdef @*/
-    gpsd_report(LOG_RAW, "EverMore packet type 0x%02x, length %zd: %s\n",
-		type, datalen, gpsd_hexdump_wrapper(buf2, datalen, LOG_RAW));
+    gpsd_report(LOG_RAW, "EverMore packet type 0x%02x\n", type);
     /*@ +usedef +compdef @*/
 
     (void)snprintf(session->gpsdata.tag, sizeof(session->gpsdata.tag),
@@ -206,21 +202,21 @@ gps_mask_t evermore_parse(struct gps_device_t * session, unsigned char *buf,
 	    session->newdata.mode = MODE_2D;
 	else {
 	    session->newdata.mode = MODE_3D;
-	    mask |= ALTITUDE_IS | CLIMB_IS;
+	    mask |= ALTITUDE_SET | CLIMB_SET;
 	}
-	mask |= TIME_IS | LATLON_IS | TRACK_IS | SPEED_IS | MODE_IS;
+	mask |= TIME_SET | PPSTIME_IS | LATLON_SET | TRACK_SET | SPEED_SET | MODE_SET;
 	if (session->subtype[0] == '\0') {
 	    (void)snprintf(session->subtype, sizeof(session->subtype),
 			   "%3.2f", version);
-	    mask |= DEVICEID_IS;
+	    mask |= DEVICEID_SET;
 	}
 	gpsd_report(LOG_DATA,
-		    "NDO 0x02: time=%.2f, lat=%.2f lon=%.2f alt=%.2f speed=%.2f track=%.2f climb=%.2f mode=%d subtype='%s' mask=%s\n",
+		    "NDO 0x02: time=%.2f, lat=%.2f lon=%.2f alt=%.2f speed=%.2f track=%.2f climb=%.2f mode=%d subtype='%s\n",
 		    session->newdata.time, session->newdata.latitude,
 		    session->newdata.longitude, session->newdata.altitude,
 		    session->newdata.speed, session->newdata.track,
 		    session->newdata.climb, session->newdata.mode,
-		    session->gpsdata.dev.subtype, gpsd_maskdump(mask));
+		    session->gpsdata.dev.subtype);
 	return mask | CLEAR_IS | REPORT_IS;
 
     case 0x04:			/* DOP Data Output */
@@ -258,7 +254,7 @@ gps_mask_t evermore_parse(struct gps_device_t * session, unsigned char *buf,
 	    break;
 	}
 	/* that's all the information in this packet */
-	mask = TIME_IS | DOP_IS | MODE_IS | STATUS_IS;
+	mask = TIME_SET | PPSTIME_IS | DOP_SET | MODE_SET | STATUS_SET;
 	gpsd_report(LOG_DATA,
 		    "DDO 0x04: gdop=%.2f pdop=%.2f hdop=%.2f vdop=%.2f tdop=%.2f mode=%d, status=%d mask={TIME| DOP|MODE|STATUS}\n",
 		    session->gpsdata.dop.gdop, session->gpsdata.dop.pdop,
@@ -313,7 +309,7 @@ gps_mask_t evermore_parse(struct gps_device_t * session, unsigned char *buf,
 	}
 	session->gpsdata.satellites_visible = (int)satcnt;
 	/* that's all the information in this packet */
-	mask = SATELLITE_IS | USED_IS;
+	mask = SATELLITE_SET | USED_IS;
 	gpsd_report(LOG_DATA,
 		    "CSO 0x06: time=%.2f used=%d visible=%d mask={TIME|SATELLITE|USED}\n",
 		    session->newdata.time, session->gpsdata.satellites_used,
@@ -359,27 +355,24 @@ gps_mask_t evermore_parse(struct gps_device_t * session, unsigned char *buf,
 #undef UBITS
 	gpsd_report(LOG_DATA, "MDO 0x04: time=%.2f mask={TIME|RAW}\n",
 		    session->newdata.time);
-	return TIME_IS | RAW_IS;
+	return TIME_SET | PPSTIME_IS | RAW_IS;
 
     case 0x20:			/* LogConfig Info, could be used as a probe for EverMore GPS */
-	gpsd_report(LOG_IO, "LogConfig EverMore packet, length %zd: %s\n",
-		    datalen, gpsd_hexdump_wrapper(buf2, datalen, LOG_IO));
-	return ONLINE_IS;
+	gpsd_report(LOG_IO, "LogConfig EverMore packet, length %zd\n", datalen);
+	return ONLINE_SET;
 
     case 0x22:			/* LogData */
-	gpsd_report(LOG_IO, "LogData EverMore packet, length %zd: %s\n",
-		    datalen, gpsd_hexdump_wrapper(buf2, datalen, LOG_IO));
-	return ONLINE_IS;
+	gpsd_report(LOG_IO, "LogData EverMore packet, length %zd\n", datalen);
+	return ONLINE_SET;
 
     case 0x38:			/* ACK */
 	gpsd_report(LOG_PROG, "EverMore command %02X ACK\n", getub(buf2, 2));
-	return ONLINE_IS;
+	return ONLINE_SET;
 
     default:
 	gpsd_report(LOG_WARN,
-		    "unknown EverMore packet EID 0x%02x, length %zd: %s\n",
-		    buf2[0], datalen, gpsd_hexdump_wrapper(buf2, datalen,
-							   LOG_WARN));
+		    "unknown EverMore packet EID 0x%02x, length %zd\n",
+		    buf2[0], datalen);
 	return 0;
     }
 }
@@ -543,7 +536,7 @@ static void evermore_event_hook(struct gps_device_t *session, event_t event)
     }
 }
 
-#ifdef ALLOW_RECONFIGURE
+#ifdef RECONFIGURE_ENABLE
 static bool evermore_speed(struct gps_device_t *session,
 			   speed_t speed, char parity, int stopbits)
 {
@@ -606,7 +599,7 @@ static bool evermore_rate_switcher(struct gps_device_t *session, double rate)
     }
     /*@ -charint @*/
 }
-#endif /* ALLOW_RECONFIGURE */
+#endif /* RECONFIGURE_ENABLE */
 
 
 /* this is everything we export */
@@ -623,15 +616,15 @@ const struct gps_type_t evermore_binary =
     .parse_packet   = evermore_parse_input,	/* parse message packets */
     .rtcm_writer    = gpsd_write,		/* send RTCM data straight */
     .event_hook     = evermore_event_hook,	/* lifetime event handler */
-#ifdef ALLOW_RECONFIGURE
+#ifdef RECONFIGURE_ENABLE
     .speed_switcher = evermore_speed,		/* we can change baud rates */
     .mode_switcher  = evermore_mode,		/* there is a mode switcher */
     .rate_switcher  = evermore_rate_switcher,	/* change sample rate */
     .min_cycle      = 1,			/* ignore, no rate switch */
-#endif /* ALLOW_RECONFIGURE */
-#ifdef ALLOW_CONTROLSEND
+#endif /* RECONFIGURE_ENABLE */
+#ifdef CONTROLSEND_ENABLE
     .control_send   = evermore_control_send,	/* how to send a control string */
-#endif /* ALLOW_CONTROLSEND */
+#endif /* CONTROLSEND_ENABLE */
 #ifdef NTPSHM_ENABLE
     .ntp_offset     = NULL,		/* no method for NTP fudge factor */
 #endif /* NTPSHM_ ENABLE */
