@@ -80,8 +80,6 @@ static uint8_t checksum(unsigned char *buf, size_t len)
 static bool navcom_send_cmd(struct gps_device_t *session, unsigned char *cmd,
 			    size_t len)
 {
-    gpsd_report(LOG_RAW, "Navcom: command dump: %s\n",
-		gpsd_hexdump_wrapper(cmd, len, LOG_RAW));
     return (gpsd_write(session, (const char *)cmd, len) == (ssize_t) len);
 }
 
@@ -155,7 +153,7 @@ static void navcom_cmd_0x1c(struct gps_device_t *session, uint8_t mode,
 		mode, length);
 }
 
-#ifdef ALLOW_RECONFIGURE
+#ifdef RECONFIGURE_ENABLE
 /* Serial Port Configuration */
 static void navcom_cmd_0x11(struct gps_device_t *session,
 			    uint8_t port_selection)
@@ -180,7 +178,7 @@ static void navcom_cmd_0x11(struct gps_device_t *session,
     gpsd_report(LOG_IO,
 		"Navcom: serial port selection: 0x%02x\n", port_selection);
 }
-#endif /* ALLOW_RECONFIGURE */
+#endif /* RECONFIGURE_ENABLE */
 
 static void navcom_event_hook(struct gps_device_t *session, event_t event)
 {
@@ -514,9 +512,10 @@ static gps_mask_t handle_0xb1(struct gps_device_t *session)
 #undef VEL_RES
 #undef DOP_UNDEFINED
 
-    mask = LATLON_IS | ALTITUDE_IS | CLIMB_IS | SPEED_IS | TRACK_IS
-	| TIME_IS | STATUS_IS | MODE_IS | USED_IS | HERR_IS | VERR_IS
-	| TIMERR_IS | DOP_IS;
+    mask = LATLON_SET | ALTITUDE_SET | CLIMB_SET | SPEED_SET | TRACK_SET
+	| STATUS_SET | MODE_SET | USED_IS | HERR_SET | VERR_SET
+	| TIMERR_SET | DOP_SET
+	| TIME_SET | PPSTIME_IS;
     gpsd_report(LOG_DATA, "PVT 0xb1: time=%.2f, lat=%.2f lon=%.2f alt=%.f "
 		"speed=%.2f track=%.2f climb=%.2f mode=%d status=%d "
 		"epx=%.2f epy=%.2f epv=%.2f "
@@ -707,8 +706,7 @@ static gps_mask_t handle_0x81(struct gps_device_t *session)
 static gps_mask_t handle_0x86(struct gps_device_t *session)
 {
     size_t n, i;
-    uint8_t prn, tracking_status, ele, ca_snr, p2_snr, log_channel,
-	hw_channel, s;
+    uint8_t prn, ele, ca_snr, p2_snr, log_channel, hw_channel, s;
     uint16_t azm, dgps_age;
     unsigned char *buf = session->packet.outbuffer + 3;
     size_t msg_len = (size_t) getleu16(buf, 1);
@@ -762,7 +760,7 @@ static gps_mask_t handle_0x86(struct gps_device_t *session)
 	    return 0;
 	}
 	prn = getub(buf, n);
-	tracking_status = getub(buf, n + 1);
+	/* tracking_status = getub(buf, n + 1); */
 	log_channel = getub(buf, n + 2);
 	ele = getub(buf, n + 5);
 	azm = getleu16(buf, n + 6);
@@ -805,7 +803,7 @@ static gps_mask_t handle_0x86(struct gps_device_t *session)
 		"CS 0x86: visible=%d, used=%d, mask={SATELLITE|STATUS}\n",
 		session->gpsdata.satellites_visible,
 		session->gpsdata.satellites_used);
-    return SATELLITE_IS | STATUS_IS;
+    return SATELLITE_SET | STATUS_SET;
 }
 
 /* Raw Meas. Data Block */
@@ -888,7 +886,7 @@ static gps_mask_t handle_0xb0(struct gps_device_t *session)
 static gps_mask_t handle_0xb5(struct gps_device_t *session)
 {
     if (sizeof(double) == 8) {
-	gps_mask_t mask = TIME_IS;
+	gps_mask_t mask = TIME_SET;
 	union long_double l_d;
 	unsigned char *buf = session->packet.outbuffer + 3;
 	uint16_t week = getleu16(buf, 3);
@@ -912,7 +910,7 @@ static gps_mask_t handle_0xb5(struct gps_device_t *session)
 #ifdef __UNUSED__
 	session->newdata.eph = hrms * 1.96;
 	session->newdata.epv = alt_sd * 1.96;
-	mask |= (HERR_IS | VERR_IS);
+	mask |= (HERR_SET | VERR_SET);
 #endif /*  __UNUSED__ */
 	session->newdata.time = gpsd_gpstime_resolve(session,
 						  (unsigned short)week,
@@ -1071,7 +1069,7 @@ static gps_mask_t handle_0xae(struct gps_device_t *session)
 		   engconfstr, asicstr, swvermaj, swvermin, slsbn, dcser,
 		   dcclass, rfcser, rfcclass);
     /*@ +formattype @*/
-    return DEVICEID_IS;
+    return DEVICEID_SET;
     /*@+modobserver@*/
 }
 
@@ -1119,19 +1117,17 @@ gps_mask_t navcom_parse(struct gps_device_t * session, unsigned char *buf,
 			size_t len)
 {
     unsigned char cmd_id;
-    unsigned char *payload;
     unsigned int msg_len;
 
     if (len == 0)
 	return 0;
 
     cmd_id = (unsigned char)getub(buf, 3);
-    payload = &buf[6];
+    //payload = &buf[6];
     msg_len = (uint) getleu16(buf, 4);
 
     /*@ -usedef -compdef @*/
-    gpsd_report(LOG_RAW, "Navcom: packet type 0x%02x, length %d: %s\n",
-		cmd_id, msg_len, gpsd_hexdump_wrapper(buf, len, LOG_RAW));
+    gpsd_report(LOG_RAW, "Navcom: packet type 0x%02x\n", cmd_id);
     /*@ +usedef +compdef @*/
 
     (void)snprintf(session->gpsdata.tag, sizeof(session->gpsdata.tag),
@@ -1191,7 +1187,7 @@ static gps_mask_t navcom_parse_input(struct gps_device_t *session)
 	return 0;
 }
 
-#ifdef ALLOW_CONTROLSEND
+#ifdef CONTROLSEND_ENABLE
 static ssize_t navcom_control_send(struct gps_device_t *session,
 				   char *buf, size_t len)
 {
@@ -1207,14 +1203,11 @@ static ssize_t navcom_control_send(struct gps_device_t *session,
     putbyte(session->msgbuf, 7 + len, 0x03);
     session->msgbuflen = len + 9;
     /*@ -ignoresigns +mayaliasunique @*/
-    gpsd_report(LOG_RAW, "Navcom: control dump: %s\n",
-		gpsd_hexdump_wrapper(session->msgbuf, session->msgbuflen,
-				     LOG_RAW));
     return gpsd_write(session, session->msgbuf, session->msgbuflen);
 }
-#endif /* ALLOW_CONTROLSEND */
+#endif /* CONTROLSEND_ENABLE */
 
-#ifdef ALLOW_RECONFIGURE
+#ifdef RECONFIGURE_ENABLE
 static bool navcom_speed(struct gps_device_t *session,
 			 speed_t speed, char parity, int stopbits)
 {
@@ -1282,7 +1275,7 @@ static bool navcom_speed(struct gps_device_t *session,
 	return true;
     }
 }
-#endif /* ALLOW_RECONFIGURE */
+#endif /* RECONFIGURE_ENABLE */
 
 /* this is everything we export */
 /* *INDENT-OFF* */
@@ -1298,15 +1291,15 @@ const struct gps_type_t navcom_binary =
     .parse_packet   = navcom_parse_input,	/* parse message packets */
     .rtcm_writer    = gpsd_write,		/* send RTCM data straight */
     .event_hook     = navcom_event_hook,	/* lifetime event handler */
-#ifdef ALLOW_RECONFIGURE
+#ifdef RECONFIGURE_ENABLE
     .speed_switcher = navcom_speed,		/* we do change baud rates */
     .mode_switcher  = NULL,			/* there is not a mode switcher */
     .rate_switcher  = NULL,			/* no sample-rate switcher */
     .min_cycle      = 1,			/* ignore, no rate switch */
-#endif /* ALLOW_RECONFIGURE */
-#ifdef ALLOW_CONTROLSEND
+#endif /* RECONFIGURE_ENABLE */
+#ifdef CONTROLSEND_ENABLE
     .control_send   = navcom_control_send,	/* how to send a control string */
-#endif /* ALLOW_CONTROLSEND */
+#endif /* CONTROLSEND_ENABLE */
 #ifdef NTPSHM_ENABLE
     .ntp_offset     = NULL,		/* no method for NTP fudge factor */
 #endif /* NTPSHM_ ENABLE */
