@@ -36,9 +36,6 @@ static int tsip_write(struct gps_device_t *session,
 {
     char *ep, *cp;
 
-    gpsd_report(LOG_IO, "Sent TSIP packet id 0x%02x: %s\n", id,
-		gpsd_hexdump_wrapper(buf, len, LOG_IO));
-
     /*@ +charint @*/
     session->msgbuf[0] = '\x10';
     session->msgbuf[1] = (char)id;
@@ -54,6 +51,7 @@ static int tsip_write(struct gps_device_t *session,
     *ep++ = '\x03';
     session->msgbuflen = (size_t) (ep - session->msgbuf);
     /*@ -charint @*/
+    gpsd_report(LOG_IO, "Sent TSIP packet id 0x%02x\n", id);
     if (gpsd_write(session, session->msgbuf, session->msgbuflen) !=
 	(ssize_t) session->msgbuflen)
 	return -1;
@@ -197,7 +195,7 @@ static gps_mask_t tsip_analyze(struct gps_device_t *session)
 	    session->context->valid |= LEAP_SECOND_VALID;
 	    session->newdata.time = 
 		gpsd_gpstime_resolve(session, (unsigned short)s1, (double)f1);
-	    mask |= TIME_IS;
+	    mask |= TIME_SET | PPSTIME_IS;
 	}
 	gpsd_report(LOG_INF, "GPS Time %f %d %f\n", f1, s1, f2);
 	break;
@@ -235,7 +233,7 @@ static gps_mask_t tsip_analyze(struct gps_device_t *session)
 		       getub(buf, 7), getub(buf, 8));
 	/*@ +formattype @*/
 	gpsd_report(LOG_INF, "Software version: %s\n", session->subtype);
-	mask |= DEVICEID_IS;
+	mask |= DEVICEID_SET;
 	break;
     case 0x46:			/* Health of Receiver */
 	if (len != 2)
@@ -245,11 +243,11 @@ static gps_mask_t tsip_analyze(struct gps_device_t *session)
 	u2 = getub(buf, 1);	/* Antenna/Battery */
 	if (u1 != (uint8_t) 0) {
 	    session->gpsdata.status = STATUS_NO_FIX;
-	    mask |= STATUS_IS;
+	    mask |= STATUS_SET;
 	} else {
 	    if (session->gpsdata.status < STATUS_FIX) {
 		session->gpsdata.status = STATUS_FIX;
-		mask |= STATUS_IS;
+		mask |= STATUS_SET;
 	    }
 	}
 	gpsd_report(LOG_PROG, "Receiver health %02x %02x\n", u1, u2);
@@ -273,7 +271,7 @@ static gps_mask_t tsip_analyze(struct gps_device_t *session)
 			   " %d=%.1f", (int)u1, f1);
 	}
 	gpsd_report(LOG_PROG, "Signal Levels (%d):%s\n", count, buf2);
-	mask |= SATELLITE_IS;
+	mask |= SATELLITE_SET;
 	break;
     case 0x48:			/* GPS System Message */
 	buf[len] = '\0';
@@ -287,22 +285,22 @@ static gps_mask_t tsip_analyze(struct gps_device_t *session)
 	session->newdata.latitude = getbef(buf, 0) * RAD_2_DEG;
 	session->newdata.longitude = getbef(buf, 4) * RAD_2_DEG;
 	session->newdata.altitude = getbef(buf, 8);
-	f1 = getbef(buf, 12);	/* clock bias */
+	//f1 = getbef(buf, 12);	clock bias */
 	f2 = getbef(buf, 16);	/* time-of-fix */
 	if ((session->context->valid & GPS_TIME_VALID)!=0) {
 	    session->newdata.time = 
 		gpsd_gpstime_resolve(session,
 				  (unsigned short)session->context->gps_week,
 				  (double)f2);
-	    mask |= TIME_IS;
+	    mask |= TIME_SET | PPSTIME_IS;
 	}
-	mask |= LATLON_IS | ALTITUDE_IS | CLEAR_IS | REPORT_IS;
+	mask |= LATLON_SET | ALTITUDE_SET | CLEAR_IS | REPORT_IS;
 	gpsd_report(LOG_DATA, "SPPLLA 0x4a "
-		    "time=%.2f lat=%.2f lon=%.2f alt=%.2f mask=%s\n",
+		    "time=%.2f lat=%.2f lon=%.2f alt=%.2f\n",
 		    session->newdata.time,
 		    session->newdata.latitude,
 		    session->newdata.longitude,
-		    session->newdata.altitude, gpsd_maskdump(mask));
+		    session->newdata.altitude);
 	break;
     case 0x4b:			/* Machine/Code ID and Additional Status */
 	if (len != 3)
@@ -369,13 +367,13 @@ static gps_mask_t tsip_analyze(struct gps_device_t *session)
 	    session->newdata.track += 360.0;
 	gpsd_report(LOG_INF, "GPS Velocity ENU %f %f %f %f %f\n", f1, f2, f3,
 		    f4, f5);
-	mask |= SPEED_IS | TRACK_IS | CLIMB_IS;
+	mask |= SPEED_SET | TRACK_SET | CLIMB_SET;
 	gpsd_report(LOG_DATA, "VFENU 0x56 "
-		    "time=%.2f speed=%.2f track=%.2f climb=%.2f mask=%s\n",
+		    "time=%.2f speed=%.2f track=%.2f climb=%.2f\n",
 		    session->newdata.time,
 		    session->newdata.speed,
 		    session->newdata.track,
-		    session->newdata.climb, gpsd_maskdump(mask));
+		    session->newdata.climb);
 	break;
     case 0x57:			/* Information About Last Computed Fix */
 	if (len != 8)
@@ -434,7 +432,7 @@ static gps_mask_t tsip_analyze(struct gps_device_t *session)
 	    }
 	    if (++i == session->gpsdata.satellites_visible) {
 		session->gpsdata.skyview_time = NAN;
-		mask |= SATELLITE_IS;	/* last of the series */
+		mask |= SATELLITE_SET;	/* last of the series */
 	    }
 	    if (i > session->gpsdata.satellites_visible)
 		session->gpsdata.satellites_visible = i;
@@ -471,7 +469,7 @@ static gps_mask_t tsip_analyze(struct gps_device_t *session)
 	    session->newdata.mode = MODE_NO_FIX;
 	    break;
 	}
-	mask |= MODE_IS;
+	mask |= MODE_SET;
 #endif /* __UNUSED__ */
 	session->gpsdata.satellites_used = count;
 	session->gpsdata.dop.pdop = getbef(buf, 1);
@@ -494,19 +492,19 @@ static gps_mask_t tsip_analyze(struct gps_device_t *session)
 	/*@ -charint @*/
 	gpsd_report(LOG_DATA, "AIVSS: 0x6d "
 		    "status=%d used=%d "
-		    "pdop=%.1f hdop=%.1f vdop=%.1f tdop=%.1f gdup=%.1f "
-		    "mask=%s\n",
+		    "pdop=%.1f hdop=%.1f vdop=%.1f tdop=%.1f gdup=%.1f\n",
 		    session->gpsdata.status,
 		    session->gpsdata.satellites_used,
 		    session->gpsdata.dop.pdop,
 		    session->gpsdata.dop.hdop,
 		    session->gpsdata.dop.vdop,
 		    session->gpsdata.dop.tdop,
-		    session->gpsdata.dop.gdop, gpsd_maskdump(mask));
-	mask |= DOP_IS | STATUS_IS | USED_IS;
+		    session->gpsdata.dop.gdop);
+	mask |= DOP_SET | STATUS_SET | USED_IS;
 	break;
     case 0x6e:			/* Synchronized Measurements */
 	break;
+#ifdef __UNUSED__
     case 0x6f:			/* Synchronized Measurements Report */
 	/*@ +charint @*/
 	if (len < 20 || getub(buf, 0) != 1 || getub(buf, 1) != 2)
@@ -515,6 +513,7 @@ static gps_mask_t tsip_analyze(struct gps_device_t *session)
 	s1 = getbes16(buf, 2);	/* number of bytes */
 	u1 = getub(buf, 20);	/* number of SVs */
 	break;
+#endif /* __UNUSED__ */
     case 0x70:			/* Filter Report */
 	break;
     case 0x7a:			/* NMEA settings */
@@ -526,11 +525,10 @@ static gps_mask_t tsip_analyze(struct gps_device_t *session)
 	/*@ +charint @*/
 	if (session->gpsdata.status == STATUS_FIX && (u1 & 0x01) != 0) {
 	    session->gpsdata.status = STATUS_DGPS_FIX;
-	    mask |= STATUS_IS;
+	    mask |= STATUS_SET;
 	}
 	/*@ -charint @*/
-	gpsd_report(LOG_DATA, "DPFM 0x82 status=%d mask=%s\n",
-		    session->gpsdata.status, gpsd_maskdump(mask));
+	gpsd_report(LOG_DATA, "DPFM 0x82 status=%d\n", session->gpsdata.status);
 	break;
     case 0x83:			/* Double-Precision XYZ Position Fix and Bias Information */
 	if (len != 36)
@@ -549,26 +547,26 @@ static gps_mask_t tsip_analyze(struct gps_device_t *session)
 	session->newdata.latitude = getbed(buf, 0) * RAD_2_DEG;
 	session->newdata.longitude = getbed(buf, 8) * RAD_2_DEG;
 	session->newdata.altitude = getbed(buf, 16);
-	d1 = getbed(buf, 24);	/* clock bias */
+	//d1 = getbed(buf, 24);	clock bias */
 	f1 = getbef(buf, 32);	/* time-of-fix */
 	if ((session->context->valid & GPS_TIME_VALID)!=0) {
 	    session->newdata.time =
 		gpsd_gpstime_resolve(session,
 				  (unsigned short)session->context->gps_week, 
 				  (double)f1);
-	    mask |= TIME_IS;
+	    mask |= TIME_SET | PPSTIME_IS;
 	}
 	gpsd_report(LOG_INF, "GPS DP LLA %f %f %f %f\n",
 		    session->newdata.time,
 		    session->newdata.latitude,
 		    session->newdata.longitude, session->newdata.altitude);
-	mask |= LATLON_IS | ALTITUDE_IS | CLEAR_IS | REPORT_IS;
+	mask |= LATLON_SET | ALTITUDE_SET | CLEAR_IS | REPORT_IS;
 	gpsd_report(LOG_DATA, "DPPLLA 0x84 "
-		    "time=%.2f lat=%.2f lon=%.2f alt=%.2f mask=%s\n",
+		    "time=%.2f lat=%.2f lon=%.2f alt=%.2f\n",
 		    session->newdata.time,
 		    session->newdata.latitude,
 		    session->newdata.longitude,
-		    session->newdata.altitude, gpsd_maskdump(mask));
+		    session->newdata.altitude);
 	break;
     case 0x8f:			/* Super Packet.  Well...  */
 	/*@ +charint @*/
@@ -653,17 +651,18 @@ static gps_mask_t tsip_analyze(struct gps_device_t *session)
 						      (unsigned short)s4, 
 						      (double)ul1 *1e-3);
 	    mask |=
-		TIME_IS | LATLON_IS | ALTITUDE_IS | SPEED_IS | TRACK_IS |
-		CLIMB_IS | STATUS_IS | MODE_IS | CLEAR_IS | REPORT_IS;
+		TIME_SET | PPSTIME_IS | LATLON_SET | ALTITUDE_SET | SPEED_SET | 
+		TRACK_SET | CLIMB_SET | STATUS_SET | MODE_SET | CLEAR_IS |
+		REPORT_IS;
 	    gpsd_report(LOG_DATA,
 			"SP-LFEI 0x20: time=%.2f lat=%.2f lon=%.2f alt=%.2f "
 			"speed=%.2f track=%.2f climb=%.2f "
-			"mode=%d status=%d mask=%s\n", session->newdata.time,
+			"mode=%d status=%d\n", 
+			session->newdata.time,
 			session->newdata.latitude, session->newdata.longitude,
 			session->newdata.altitude, session->newdata.speed,
 			session->newdata.track, session->newdata.climb,
-			session->newdata.mode, session->gpsdata.status,
-			gpsd_maskdump(mask));
+			session->newdata.mode, session->gpsdata.status);
 	    break;
 	case 0x23:		/* Compact Super Packet */
 	    session->driver.tsip.req_compact = 0;
@@ -723,17 +722,17 @@ static gps_mask_t tsip_analyze(struct gps_device_t *session)
 	    if ((session->newdata.track = atan2(d1, d2) * RAD_2_DEG) < 0)
 		session->newdata.track += 360.0;
 	    mask |=
-		TIME_IS | LATLON_IS | ALTITUDE_IS | SPEED_IS | TRACK_IS |
-		CLIMB_IS | STATUS_IS | MODE_IS | CLEAR_IS | REPORT_IS;
+		TIME_SET | PPSTIME_IS | LATLON_SET | ALTITUDE_SET | SPEED_SET |
+		TRACK_SET |CLIMB_SET | STATUS_SET | MODE_SET | CLEAR_IS |
+		REPORT_IS;
 	    gpsd_report(LOG_DATA,
 			"SP-CSP 0x23: time=%.2f lat=%.2f lon=%.2f alt=%.2f "
-			"speed=%.2f track=%.2f climb=%.2f "
-			"mode=%d status=%d mask=%s\n", session->newdata.time,
+			"speed=%.2f track=%.2f climb=%.2f mode=%d status=%d\n", 
+			session->newdata.time,
 			session->newdata.latitude, session->newdata.longitude,
 			session->newdata.altitude, session->newdata.speed,
 			session->newdata.track, session->newdata.climb,
-			session->newdata.mode, session->gpsdata.status,
-			gpsd_maskdump(mask));
+			session->newdata.mode, session->gpsdata.status);
 	    break;
 
 	case 0xab:		/* Thunderbolt Timing Superpacket */
@@ -751,7 +750,7 @@ static gps_mask_t tsip_analyze(struct gps_device_t *session)
 		session->context->valid |= LEAP_SECOND_VALID;
 		session->newdata.time =
 		    gpsd_gpstime_resolve(session, (unsigned short)s1, (double)ul1);
-		mask |= TIME_IS | CLEAR_IS;
+		mask |= TIME_SET | PPSTIME_IS | CLEAR_IS;
 		gpsd_report(LOG_DATA, "SP-TTS 0xab time=%.2f mask={TIME}\n",
 			    session->newdata.time);
 	    }
@@ -769,17 +768,17 @@ static gps_mask_t tsip_analyze(struct gps_device_t *session)
 	    session->newdata.latitude = getbed(buf, 36) * RAD_2_DEG;
 	    session->newdata.longitude = getbed(buf, 44) * RAD_2_DEG;
 	    session->newdata.altitude = getbed(buf, 52);
-	    f1 = getbef(buf, 16);	/* clock bias */
+	    //f1 = getbef(buf, 16);    clock bias */
 
 	    u1 = getub(buf, 12);	/* GPS Decoding Status */
 	    u2 = getub(buf, 1);	/* Receiver Mode */
 	    if (u1 != (uint8_t) 0) {
 		session->gpsdata.status = STATUS_NO_FIX;
-		mask |= STATUS_IS;
+		mask |= STATUS_SET;
 	    } else {
 		if (session->gpsdata.status < STATUS_FIX) {
 		    session->gpsdata.status = STATUS_FIX;
-		    mask |= STATUS_IS;
+		    mask |= STATUS_SET;
 		}
 	    }
 
@@ -827,16 +826,15 @@ static gps_mask_t tsip_analyze(struct gps_device_t *session)
 		break;
 	    }
 
-	    mask |= LATLON_IS | ALTITUDE_IS | MODE_IS | REPORT_IS;
+	    mask |= LATLON_SET | ALTITUDE_SET | MODE_SET | REPORT_IS;
 	    gpsd_report(LOG_DATA, "SP-TPS 0xac "
-			"time=%.2f lat=%.2f lon=%.2f alt=%.2f mask=%s\n",
+			"time=%.2f lat=%.2f lon=%.2f alt=%.2f\n",
 			session->newdata.time,
 			session->newdata.latitude,
 			session->newdata.longitude,
-			session->newdata.altitude, gpsd_maskdump(mask));
+			session->newdata.altitude);
 	    break;
 
-
 	default:
 	    gpsd_report(LOG_WARN, "Unhandled TSIP superpacket type 0x%02x\n",
 			u1);
@@ -947,7 +945,7 @@ static gps_mask_t tsip_parse_input(struct gps_device_t *session)
 	return 0;
 }
 
-#ifdef ALLOW_CONTROLSEND
+#ifdef CONTROLSEND_ENABLE
 static ssize_t tsip_control_send(struct gps_device_t *session,
 				 char *buf, size_t buflen)
 /* not used by the daemon, it's for gpsctl and friends */
@@ -956,7 +954,7 @@ static ssize_t tsip_control_send(struct gps_device_t *session,
 				(unsigned int)buf[0],
 				(unsigned char *)buf + 1, buflen - 1);
 }
-#endif /* ALLOW_CONTROLSEND */
+#endif /* CONTROLSEND_ENABLE */
 
 static void tsip_event_hook(struct gps_device_t *session, event_t event)
 {
@@ -1039,7 +1037,7 @@ static void tsip_event_hook(struct gps_device_t *session, event_t event)
     }
 }
 
-#ifdef ALLOW_RECONFIGURE
+#ifdef RECONFIGURE_ENABLE
 static bool tsip_speed_switch(struct gps_device_t *session,
 			      speed_t speed, char parity, int stopbits)
 {
@@ -1121,7 +1119,7 @@ static void tsip_mode(struct gps_device_t *session, int mode)
 	gpsd_report(LOG_ERROR, "unknown mode %i requested\n", mode);
     }
 }
-#endif /* ALLOW_RECONFIGURE */
+#endif /* RECONFIGURE_ENABLE */
 
 #ifdef NTPSHM_ENABLE
 static double tsip_ntp_offset(struct gps_device_t *session UNUSED)
@@ -1145,15 +1143,15 @@ const struct gps_type_t tsip_binary =
     .parse_packet   = tsip_parse_input,	/* parse message packets */
     .rtcm_writer    = NULL,		/* doesn't accept DGPS corrections */
     .event_hook     = tsip_event_hook,	/* fire on various lifetime events */
-#ifdef ALLOW_RECONFIGURE
+#ifdef RECONFIGURE_ENABLE
     .speed_switcher = tsip_speed_switch,/* change baud rate */
     .mode_switcher  = tsip_mode,	/* there is a mode switcher */
     .rate_switcher  = NULL,		/* no rate switcher */
     .min_cycle      = 1,		/* not relevant, no rate switcher */
-#endif /* ALLOW_RECONFIGURE */
-#ifdef ALLOW_CONTROLSEND
+#endif /* RECONFIGURE_ENABLE */
+#ifdef CONTROLSEND_ENABLE
     .control_send   = tsip_control_send,/* how to send commands */
-#endif /* ALLOW_CONTROLSEND */
+#endif /* CONTROLSEND_ENABLE */
 #ifdef NTPSHM_ENABLE
     .ntp_offset     = tsip_ntp_offset,
 #endif /* NTPSHM_ENABLE */
