@@ -74,7 +74,7 @@ ubx_msg_nav_sol(struct gps_device_t *session, unsigned char *buf,
 	tow = (unsigned int)getleu32(buf, 0);
 	gw = (unsigned short)getles16(buf, 8);
 	session->newdata.time = gpsd_gpstime_resolve(session, gw, tow / 1000.0);
-	mask |= TIME_IS;
+	mask |= TIME_SET | PPSTIME_IS;
     }
 
     epx = (double)(getles32(buf, 12) / 100.0);
@@ -85,7 +85,7 @@ ubx_msg_nav_sol(struct gps_device_t *session, unsigned char *buf,
     evz = (double)(getles32(buf, 36) / 100.0);
     ecef_to_wgs84fix(&session->newdata, &session->gpsdata.separation,
 		     epx, epy, epz, evx, evy, evz);
-    mask |= LATLON_IS | ALTITUDE_IS | SPEED_IS | TRACK_IS | CLIMB_IS;
+    mask |= LATLON_SET | ALTITUDE_SET | SPEED_SET | TRACK_SET | CLIMB_SET;
     session->newdata.epx = session->newdata.epy =
 	(double)(getles32(buf, 24) / 100.0) / sqrt(2);
     session->newdata.eps = (double)(getles32(buf, 40) / 100.0);
@@ -113,9 +113,9 @@ ubx_msg_nav_sol(struct gps_device_t *session, unsigned char *buf,
     else if (session->newdata.mode != MODE_NO_FIX)
 	session->gpsdata.status = STATUS_FIX;
 
-    mask |= MODE_IS | STATUS_IS;
+    mask |= MODE_SET | STATUS_SET;
     gpsd_report(LOG_DATA,
-		"NAVSOL: time=%.2f lat=%.2f lon=%.2f alt=%.2f track=%.2f speed=%.2f climb=%.2f mode=%d status=%d used=%d mask=%s\n",
+		"NAVSOL: time=%.2f lat=%.2f lon=%.2f alt=%.2f track=%.2f speed=%.2f climb=%.2f mode=%d status=%d used=%d\n",
 		session->newdata.time,
 		session->newdata.latitude,
 		session->newdata.longitude,
@@ -125,7 +125,7 @@ ubx_msg_nav_sol(struct gps_device_t *session, unsigned char *buf,
 		session->newdata.climb,
 		session->newdata.mode,
 		session->gpsdata.status,
-		session->gpsdata.satellites_used, gpsd_maskdump(mask));
+		session->gpsdata.satellites_used);
     return mask;
 }
 
@@ -156,7 +156,7 @@ ubx_msg_nav_dop(struct gps_device_t *session, unsigned char *buf,
 		session->gpsdata.dop.hdop,
 		session->gpsdata.dop.vdop,
 		session->gpsdata.dop.pdop, session->gpsdata.dop.tdop);
-    return DOP_IS;
+    return DOP_SET;
 }
 
 /**
@@ -182,7 +182,7 @@ ubx_msg_nav_timegps(struct gps_device_t *session, unsigned char *buf,
 
     gpsd_report(LOG_DATA, "TIMEGPS: time=%.2f mask={TIME}\n",
 		session->newdata.time);
-    return TIME_IS;
+    return TIME_SET | PPSTIME_IS;
 }
 
 /**
@@ -234,7 +234,7 @@ ubx_msg_nav_svinfo(struct gps_device_t *session, unsigned char *buf,
 		"SVINFO: visible=%d used=%d mask={SATELLITE|USED}\n",
 		session->gpsdata.satellites_visible,
 		session->gpsdata.satellites_used);
-    return SATELLITE_IS | USED_IS;
+    return SATELLITE_SET | USED_IS;
 }
 
 /*
@@ -479,15 +479,15 @@ gps_mask_t ubx_parse(struct gps_device_t * session, unsigned char *buf,
 
     default:
 	gpsd_report(LOG_WARN,
-		    "UBX: unknown packet id 0x%04hx (length %zd) %s\n",
-		    msgid, len, gpsd_hexdump_wrapper(buf, len, LOG_WARN));
+		    "UBX: unknown packet id 0x%04hx (length %zd)\n",
+		    msgid, len);
     }
 
     if (mask)
 	(void)snprintf(session->gpsdata.tag, sizeof(session->gpsdata.tag),
 		       "0x%04hx", msgid);
 
-    return mask | ONLINE_IS;
+    return mask | ONLINE_SET;
 }
 
 /*@ -charint @*/
@@ -506,15 +506,6 @@ static gps_mask_t parse_input(struct gps_device_t *session)
 	session->gpsdata.dev.driver_mode = MODE_NMEA;
 #endif /* NMEA_ENABLE */
     }
-#ifdef NTPSHM_ENABLE
-    if (session->context->enable_ntpshm 
-	&& 0 != (st & TIME_SET)
-	&& (session->gpsdata.fix.time != session->last_fixtime)) {
-	    /* FIXME!! this needs an empirical fudge */
-	    (void)ntpshm_put(session, session->gpsdata.fix.time, 0);
-	    session->last_fixtime = session->gpsdata.fix.time;
-    }
-#endif /* NTPSHM_ENABLE */
     return st;
 }
 
@@ -557,20 +548,16 @@ bool ubx_write(struct gps_device_t * session,
     /*@ +type @*/
 
     gpsd_report(LOG_IO,
-		"=> GPS: UBX class: %02x, id: %02x, len: %d, data:%s, crc: %02x%02x\n",
+		"=> GPS: UBX class: %02x, id: %02x, len: %d, crc: %02x%02x\n",
 		msg_class, msg_id, data_len,
-		gpsd_hexdump_wrapper(msg, (size_t) data_len, LOG_IO),
 		CK_A, CK_B);
-
-    count = write(session->gpsdata.gps_fd,
-		  session->msgbuf, session->msgbuflen);
-    (void)tcdrain(session->gpsdata.gps_fd);
+    count = gpsd_write(session, session->msgbuf, session->msgbuflen);
     ok = (count == (ssize_t) session->msgbuflen);
     /*@ +nullderef @*/
     return (ok);
 }
 
-#ifdef ALLOW_CONTROLSEND
+#ifdef CONTROLSEND_ENABLE
 static ssize_t ubx_control_send(struct gps_device_t *session, char *msg,
 				size_t data_len)
 /* not used by gpsd, it's for gpsctl and friends */
@@ -580,7 +567,7 @@ static ssize_t ubx_control_send(struct gps_device_t *session, char *msg,
 		     (unsigned short)(data_len - 2)) ? ((ssize_t) (data_len +
 								   7)) : -1;
 }
-#endif /* ALLOW_CONTROLSEND */
+#endif /* CONTROLSEND_ENABLE */
 
 static void ubx_catch_model(struct gps_device_t *session, unsigned char *buf,
 			    size_t len)
@@ -663,7 +650,7 @@ static void ubx_event_hook(struct gps_device_t *session, event_t event)
     }
 }
 
-#ifdef ALLOW_RECONFIGURE
+#ifdef RECONFIGURE_ENABLE
 static void ubx_nmea_mode(struct gps_device_t *session, int mode)
 {
     int i;
@@ -756,7 +743,7 @@ static bool ubx_rate(struct gps_device_t *session, double cycletime)
 
     return ubx_write(session, 0x06, 0x08, msg, 6);	/* CFG-RATE */
 }
-#endif /* ALLOW_RECONFIGURE */
+#endif /* RECONFIGURE_ENABLE */
 
 /* This is everything we export */
 /* *INDENT-OFF* */
@@ -771,15 +758,15 @@ const struct gps_type_t ubx_binary = {
     .parse_packet     = parse_input,    /* Parse message packets */
     .rtcm_writer      = gpsd_write,      /* RTCM handler (using default routine) */
     .event_hook       = ubx_event_hook,	/* Fiew in variious lifetime events */
-#ifdef ALLOW_RECONFIGURE
+#ifdef RECONFIGURE_ENABLE
     .speed_switcher   = ubx_speed,      /* Speed (baudrate) switch */
     .mode_switcher    = ubx_nmea_mode,  /* Switch to NMEA mode */
     .rate_switcher    = ubx_rate,       /* Message delivery rate switcher */
     .min_cycle        = 0.25,           /* Maximum 4Hz sample rate */
-#endif /* ALLOW_RECONFIGURE */
-#ifdef ALLOW_CONTROLSEND
+#endif /* RECONFIGURE_ENABLE */
+#ifdef CONTROLSEND_ENABLE
     .control_send     = ubx_control_send,	/* no control sender yet */
-#endif /* ALLOW_CONTROLSEND */
+#endif /* CONTROLSEND_ENABLE */
 #ifdef NTPSHM_ENABLE
     .ntp_offset     = NULL,		/* no method for NTP fudge factor */
 #endif /* NTPSHM_ ENABLE */
