@@ -107,7 +107,14 @@ static gps_mask_t get_packet(struct gps_device_t *session)
 	/*@ +usedef @*/
 
 	fieldmask = gpsd_poll(session);
-	if ((fieldmask &~ ONLINE_IS)!=0)
+
+	/* conditional prevents mask dumper from eating CPU */
+	if (debuglevel >= LOG_DATA)
+	    gpsd_report(LOG_DATA,
+			"packet mask = %s\n",
+			gps_maskdump(session->gpsdata.set));
+
+	if ((fieldmask &~ ONLINE_SET)!=0)
 	    return fieldmask;
     }
 }
@@ -171,7 +178,7 @@ static bool gps_query(/*@out@*/struct gps_data_t *gpsdata,
 	gpsd_report(LOG_PROG, "reading...\n");
 
 	(void)gps_read(gpsdata);
-	if (ERROR_IS & gpsdata->set) {
+	if (ERROR_SET & gpsdata->set) {
 	    gpsd_report(LOG_ERROR, "error '%s'\n", gpsdata->error);
 	    return false;
 	}
@@ -202,6 +209,21 @@ static void onsig(int sig)
     }
 }
 
+static char /*@observer@*/ *gpsd_id( /*@in@ */ struct gps_device_t *session)
+/* full ID of the device for reports, including subtype */
+{
+    static char buf[128];
+    if ((session == NULL) || (session->device_type == NULL) ||
+	(session->device_type->type_name == NULL))
+	return "unknown,";
+    (void)strlcpy(buf, session->device_type->type_name, sizeof(buf));
+    if (session->subtype[0] != '\0') {
+	(void)strlcat(buf, " ", sizeof(buf));
+	(void)strlcat(buf, session->subtype, sizeof(buf));
+    }
+    return (buf);
+}
+
 int main(int argc, char **argv)
 {
     int option, status, devcount;
@@ -212,10 +234,10 @@ int main(int argc, char **argv)
     struct gps_data_t gpsdata;
     const struct gps_type_t *forcetype = NULL;
     const struct gps_type_t **dp;
-#ifdef ALLOW_CONTROLSEND
+#ifdef CONTROLSEND_ENABLE
     char cooked[BUFSIZ];
     ssize_t cooklen = 0;
-#endif /* ALLOW_RECONFIGURE */
+#endif /* RECONFIGURE_ENABLE */
 
 #define USAGE	"usage: gpsctl [-l] [-b | -n | -r] [-D n] [-s speed] [-c rate] [-T timeout] [-V] [-t devtype] [-x control] [-e] <device>\n"
     while ((option = getopt(argc, argv, "bec:fhlnrs:t:x:D:T:V")) != -1) {
@@ -224,14 +246,14 @@ int main(int argc, char **argv)
 	    to_binary = true;
 	    break;
 	case 'c':
-#ifdef ALLOW_RECONFIGURE
+#ifdef RECONFIGURE_ENABLE
 	    rate = optarg;
 #else
 	    gpsd_report(LOG_ERROR, "cycle-change capability has been conditioned out.\n");
-#endif /* ALLOW_RECONFIGURE */
+#endif /* RECONFIGURE_ENABLE */
 	    break;
 	case 'x':		/* ship specified control string */
-#ifdef ALLOW_CONTROLSEND
+#ifdef CONTROLSEND_ENABLE
 	    control = optarg;
 	    lowlevel = true;
 	    if ((cooklen = hex_escapes(cooked, control)) <= 0) {
@@ -241,7 +263,7 @@ int main(int argc, char **argv)
 	    }
 #else
 	    gpsd_report(LOG_ERROR, "control_send capability has been conditioned out.\n");	    
-#endif /* ALLOW_CONTROLSEND */
+#endif /* CONTROLSEND_ENABLE */
 	    break;
 	case 'e':		/* echo specified control string with wrapper */
 	    lowlevel = true;
@@ -252,7 +274,7 @@ int main(int argc, char **argv)
 	    break;
         case 'l':		/* list known device types */
 	    for (dp = gpsd_drivers; *dp; dp++) {
-#ifdef ALLOW_RECONFIGURE
+#ifdef RECONFIGURE_ENABLE
 		if ((*dp)->mode_switcher != NULL)
 		    (void)fputs("-[bn]\t", stdout);
 		else
@@ -265,37 +287,37 @@ int main(int argc, char **argv)
 		    (void)fputs("-c\t", stdout);
 		else
 		    (void)fputc('\t', stdout);
-#endif /* ALLOW_RECONFIGURE */
-#ifdef ALLOW_CONTROLSEND
+#endif /* RECONFIGURE_ENABLE */
+#ifdef CONTROLSEND_ENABLE
 		if ((*dp)->control_send != NULL)
 		    (void)fputs("-x\t", stdout);
 		else
 		    (void)fputc('\t', stdout);
-#endif /* ALLOW_CONTROLSEND */
+#endif /* CONTROLSEND_ENABLE */
 		(void)puts((*dp)->type_name);
 	    }
 	    exit(0);
 	case 'n':		/* switch to NMEA mode */
-#ifdef ALLOW_RECONFIGURE
+#ifdef RECONFIGURE_ENABLE
 	    to_nmea = true;
 #else
 	    gpsd_report(LOG_ERROR, "speed-change capability has been conditioned out.\n");
-#endif /* ALLOW_RECONFIGURE */
+#endif /* RECONFIGURE_ENABLE */
 	    break;
 	case 'r':		/* force-switch to default mode */
-#ifdef ALLOW_RECONFIGURE
+#ifdef RECONFIGURE_ENABLE
 	    reset = true;
 	    lowlevel = false;	/* so we'll abort if the daemon is running */
 #else
 	    gpsd_report(LOG_ERROR, "reset capability has been conditioned out.\n");
-#endif /* ALLOW_RECONFIGURE */
+#endif /* RECONFIGURE_ENABLE */
 	    break;
 	case 's':		/* change output baud rate */
-#ifdef ALLOW_RECONFIGURE
+#ifdef RECONFIGURE_ENABLE
 	    speed = optarg;
 #else
 	    gpsd_report(LOG_ERROR, "speed-change capability has been conditioned out.\n");
-#endif /* ALLOW_RECONFIGURE */
+#endif /* RECONFIGURE_ENABLE */
 	    break;
 	case 't':		/* force the device type */
 	    devtype = optarg;
@@ -305,7 +327,6 @@ int main(int argc, char **argv)
 	    break;
 	case 'D':		/* set debugging level */
 	    debuglevel = atoi(optarg);
-	    gpsd_hexdump_level = debuglevel;
 #ifdef CLIENTDEBUG_ENABLE
 	    gps_enable_debug(debuglevel, stderr);
 #endif /* CLIENTDEBUG_ENABLE */
@@ -452,7 +473,7 @@ int main(int argc, char **argv)
 	}
 
 	status = 0;
-#ifdef ALLOW_RECONFIGURE
+#ifdef RECONFIGURE_ENABLE
 	if (reset)
 	{
 	    gpsd_report(LOG_PROG, "cannot reset with gpsd running.\n");
@@ -526,10 +547,10 @@ int main(int argc, char **argv)
 			    "?DEVICE={\"path\":\"%s\",\"cycle\":%s}\n", 
 			    device, rate);
 	}
-#endif /* ALLOW_RECONFIGURE */
+#endif /* RECONFIGURE_ENABLE */
 	(void)gps_close(&gpsdata);
 	exit(status);
-#ifdef ALLOW_RECONFIGURE
+#ifdef RECONFIGURE_ENABLE
     } else if (reset) {
 	/* hard reset will go through lower-level operations */
 	const int speeds[] = {2400, 4800, 9600, 19200, 38400, 57600, 115200};
@@ -543,6 +564,8 @@ int main(int argc, char **argv)
 	    }
 
 	/*@ -mustfreeonly -immediatetrans @*/
+	gps_context_init(&context);
+	context.debug = debuglevel;
 	session.context = &context;
 	gpsd_tty_init(&session);
 	(void)strlcpy(session.gpsdata.dev.path, device, sizeof(session.gpsdata.dev.path));
@@ -563,12 +586,14 @@ int main(int argc, char **argv)
 	gpsd_wrap(&session);
 	exit(0);
 	/*@ +mustfreeonly +immediatetrans @*/
-#endif /* ALLOW_RECONFIGURE */
+#endif /* RECONFIGURE_ENABLE */
     } else {
 	/* access to the daemon failed, use the low-level facilities */
 	static struct gps_context_t	context;	/* start it zeroed */
 	static struct gps_device_t	session;	/* zero this too */
 	/*@ -mustfreeonly -immediatetrans @*/
+	gps_context_init(&context);
+	context.debug = debuglevel;
 	session.context = &context;	/* in case gps_init isn't called */
 
 	if (echo)
@@ -649,7 +674,7 @@ int main(int argc, char **argv)
 
 	/* now perform the actual control function */
 	status = 0;
-#ifdef ALLOW_RECONFIGURE
+#ifdef RECONFIGURE_ENABLE
 	/*@ -nullderef @*/
 	if (to_nmea || to_binary) {
 	    bool write_enable = context.readonly;
@@ -738,8 +763,8 @@ int main(int argc, char **argv)
 	    }
 	    context.readonly = write_enable;
 	}
-#endif /* ALLOW_RECONFIGURE */
-#ifdef ALLOW_CONTROLSEND
+#endif /* RECONFIGURE_ENABLE */
+#ifdef CONTROLSEND_ENABLE
 	/*@ -compdef @*/
 	if (control) {
 	    bool write_enable = context.readonly;
@@ -761,7 +786,7 @@ int main(int argc, char **argv)
 	    context.readonly = write_enable;
 	}
 	/*@ +compdef @*/
-#endif /* ALLOW_CONTROLSEND */
+#endif /* CONTROLSEND_ENABLE */
 
 	exit(status);
 	/*@ +nullderef @*/
