@@ -24,7 +24,6 @@
 #include <syslog.h>
 #include <errno.h>
 #include <fcntl.h>
-#include <locale.h>
 #include <pthread.h>
 #ifndef S_SPLINT_S
 #include <netdb.h>
@@ -43,10 +42,6 @@
 
 #include "gpsd_config.h"
 
-#if defined(DBUS_EXPORT_ENABLE) && !defined(S_SPLINT_S)
-#include "dbusexport.h"
-#endif /* defined(DBUS_EXPORT_ENABLE) && !defined(S_SPLINT_S) */
-
 #include "gpsd.h"
 #include "sockaddr.h"
 #include "gps_json.h"
@@ -1087,13 +1082,13 @@ static void handle_request(struct subscriber_t *sub,
     } else if (strncmp(buf, "DEVICE", 6) == 0
 	       && (buf[6] == ';' || buf[6] == '=')) {
 	struct devconfig_t devconf;
-	struct gps_device_t *device;
 	buf += 6;
 	devconf.path[0] = '\0';	/* initially, no device selection */
 	if (*buf == ';') {
 	    ++buf;
 	} else {
 #ifdef RECONFIGURE_ENABLE
+	    struct gps_device_t *device;
 	    /* first, select a device to operate on */
 	    int status = json_device_read(buf + 1, &devconf, &end);
 	    if (end == NULL)
@@ -1780,6 +1775,7 @@ int main(int argc, char *argv[])
     bool go_background = true;
     struct timeval tv;
     const struct gps_type_t **dp;
+    bool in_restart;
 
 #ifdef PPS_ENABLE
     /*@-nullpass@*/
@@ -1787,7 +1783,6 @@ int main(int argc, char *argv[])
     /*@+nullpass@*/
 #endif /* PPS_ENABLE */
 
-    (void)setlocale(LC_NUMERIC, "C");
     context.debug = 0;
     gps_context_init(&context);
     while ((option = getopt(argc, argv, "F:D:S:bGhlNnP:V")) != -1) {
@@ -1989,16 +1984,22 @@ int main(int argc, char *argv[])
 	gpsd_report(LOG_PROG, "shared-segment creation succeeded,\n");
 #endif /* SHM_EXPORT_ENABLE */
 
-    /* 
-     * Drop privileges.
-     *
-     * Yes, the test for this is non-orthogonal and ugly.  The problem
-     * is that there is a line-discipline setup call in the PPS
-     * support, way later on, that require root (see ntpshm.c and
-     * look for "requires root"). We've overloaded -N with the meaning
-     * "don't drop privileges" pending a better solution.
+    /*
+     * We open devices specified on the command line *before* dropping
+     * privileges in case one of them is a serial device with PPS support
+     * and we need to set the line discipline, which requires root.
      */
-    if (getuid() == 0 && go_background) {
+    in_restart = false;
+    for (i = optind; i < argc; i++) {
+	if (!add_device(argv[i])) {
+	    gpsd_report(LOG_ERROR,
+			"initial GPS device %s open failed\n",
+			argv[i]);
+	}
+    }
+
+    /* drop privileges */
+    if (getuid() == 0) {
 	struct passwd *pw;
 	struct stat stb;
 
@@ -2049,6 +2050,7 @@ int main(int argc, char *argv[])
 	    if (allocated_device(&devices[dfd]))
 		(void)gpsd_wrap(&devices[dfd]);
 	}
+	in_restart = true;
 	gpsd_report(LOG_WARN, "gpsd restarted by SIGHUP\n");
     }
 
@@ -2072,13 +2074,19 @@ int main(int argc, char *argv[])
     /* initialize the GPS context's time fields */
     gpsd_time_init(&context, time(NULL));
 
-    for (i = optind; i < argc; i++) {
-	if (!add_device(argv[i])) {
-	    gpsd_report(LOG_ERROR,
-			"GPS device %s open failed\n",
-			argv[i]);
+    /*
+     * If we got here via SIGINT, reopen any command-line devices. PPS 
+     * through these won't work, as we've dropped privileges and can
+     * no longer change line disciplines.
+     */
+    if (in_restart)
+	for (i = optind; i < argc; i++) {
+	    if (!add_device(argv[i])) {
+		gpsd_report(LOG_ERROR,
+			    "GPS device %s open failed\n",
+			    argv[i]);
+	    }
 	}
-    }
 
     while (0 == signalled) {
 	(void)memcpy((char *)&rfds, (char *)&all_fds, sizeof(rfds));
