@@ -17,23 +17,25 @@
 #endif /* S_SPLINT_S */
 
 #include "gps.h"
+#include "gpsd_config.h"
 #include "gpsdclient.h"
 #include "revision.h"
 
+#define NITEMS(x) (int)(sizeof(x)/sizeof(x[0])) /* from gpsd.h-tail */
+
 #ifdef S_SPLINT_S
 extern struct tm *gmtime_r(const time_t *, /*@out@*/ struct tm *tp);
 #endif /* S_SPLINT_S */
 
+static char *progname;
+static struct fixsource_t source;
+
 /**************************************************************************
  *
  * Transport-layer-independent functions
  *
  **************************************************************************/
 
-static char *author = "Amaury Jacquot, Chris Kuethe";
-static char *license = "BSD";
-static char *progname;
-
 static struct gps_data_t gpsdata;
 static FILE *logfile;
 static bool intrack = false;
@@ -45,16 +47,16 @@ static int debug;
 
 static void print_gpx_header(void)
 {
+    char tbuf[CLIENT_DATE_MAX+1];
+
     (void)fprintf(logfile,"<?xml version=\"1.0\" encoding=\"utf-8\"?>\n");
-    (void)fprintf(logfile,"<gpx version=\"1.1\" creator=\"navsys logger\"\n");
+    (void)fprintf(logfile,"<gpx version=\"1.1\" creator=\"GPSD %s - http://gpsd.berlios.de/\"\n", VERSION);
     (void)fprintf(logfile,"        xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"\n");
-    (void)fprintf(logfile,"        xmlns=\"http://www.topografix.com/GPX/1.1\"\n");
-    (void)fprintf(logfile,"        xsi:schemaLocation=\"http://www.topografix.com/GPS/1/1\n");
+    (void)fprintf(logfile,"        xmlns=\"http://www.topografix.com/GPX/1/1\"\n");
+    (void)fprintf(logfile,"        xsi:schemaLocation=\"http://www.topografix.com/GPX/1/1\n");
     (void)fprintf(logfile,"        http://www.topografix.com/GPX/1/1/gpx.xsd\">\n");
     (void)fprintf(logfile," <metadata>\n");
-    (void)fprintf(logfile,"  <name>NavSys GPS logger dump</name>\n");
-    (void)fprintf(logfile,"  <author>%s</author>\n", author);
-    (void)fprintf(logfile,"  <copyright>%s</copyright>\n", license);
+    (void)fprintf(logfile,"  <time>%s</time>\n", unix_to_iso8601((timestamp_t)time(NULL), tbuf, sizeof(tbuf)));
     (void)fprintf(logfile," </metadata>\n");
     (void)fflush(logfile);
 }
@@ -77,13 +79,14 @@ static void print_gpx_footer(void)
 static void print_gpx_trk_start(void)
 {
     (void)fprintf(logfile," <trk>\n");
+    (void)fprintf(logfile,"  <src>GPSD %s</src>\n", VERSION);
     (void)fprintf(logfile,"  <trkseg>\n");
     (void)fflush(logfile);
 }
 
 static void print_fix(struct gps_data_t *gpsdata, double time)
 {
-    char tbuf[128];
+    char tbuf[CLIENT_DATE_MAX+1];
 
     (void)fprintf(logfile,"   <trkpt lat=\"%f\" lon=\"%f\">\n",
 		 gpsdata->fix.latitude, gpsdata->fix.longitude);
@@ -91,6 +94,7 @@ static void print_fix(struct gps_data_t *gpsdata, double time)
 	(void)fprintf(logfile,"    <ele>%f</ele>\n", gpsdata->fix.altitude);
     (void)fprintf(logfile,"    <time>%s</time>\n",
 		 unix_to_iso8601(time, tbuf, sizeof(tbuf)));
+    (void)fprintf(logfile,"    <src>GPSD tag=\"%s\"</src>\n", gpsdata->tag);
     if (gpsdata->status == STATUS_DGPS_FIX)
 	(void)fprintf(logfile,"    <fix>dgps</fix>\n");
     else
@@ -174,10 +178,11 @@ static void quit_handler(int signum)
     if (signum != SIGINT)
 	syslog(LOG_INFO, "exiting, signal %d received", signum);
     print_gpx_footer();
+    (void)gps_close(&gpsdata);
     exit(0);
 }
 
-#ifdef DBUS_ENABLE
+#if defined(DBUS_EXPORT_ENABLE) && !defined(S_SPLINT_S)
 /**************************************************************************
  *
  * Doing it with D-Bus
@@ -191,8 +196,6 @@ static void quit_handler(int signum)
 
 #include <glib/gprintf.h>
 
-#define EMIX(x, y)	(((x) > (y)) ? (x) : (y))
-
 DBusConnection *connection;
 
 static char gpsd_devname[BUFSIZ];
@@ -201,7 +204,7 @@ static DBusHandlerResult handle_gps_fix(DBusMessage * message)
 {
     DBusError error;
     /* this packet format was designed before we split eph */
-    double eph = EMIX(gpsdata.fix.epx, gpsdata.fix.epy);
+    double eph;
 
     dbus_error_init(&error);
 
@@ -281,20 +284,20 @@ static int dbus_mainloop(void)
 
     dbus_connection_setup_with_g_main(connection, NULL);
 
+    print_gpx_header();
     g_main_loop_run(mainloop);
     return 0;
 }
 
-#endif /* DBUS_ENABLE */
+#endif /* defined(DBUS_EXPORT_ENABLE) && !defined(S_SPLINT_S) */
 
+#ifdef SOCKET_EXPORT_ENABLE
 /**************************************************************************
  *
  * Doing it with sockets
  *
  **************************************************************************/
 
-static struct fixsource_t source;
-
 /*@-mustfreefresh -compdestroy@*/
 static int socket_mainloop(void)
 {
@@ -311,9 +314,10 @@ static int socket_mainloop(void)
 	flags |= WATCH_DEVICE;
     (void)gps_stream(&gpsdata, flags, source.device);
 
+    print_gpx_header();
     for (;;) {
 	if (!gps_waiting(&gpsdata, 5000000)) {
-	    (void)fprintf(stderr, "%s: error whille waiting\n", progname);
+	    (void)fprintf(stderr, "%s: error while waiting\n", progname);
 	    break;
 	} else {
 	    (void)gps_read(&gpsdata);
@@ -324,6 +328,41 @@ static int socket_mainloop(void)
     return 0;
 }
 /*@+mustfreefresh +compdestroy@*/
+#endif /* SOCKET_EXPORT_ENABLE */
+
+#ifdef SHM_EXPORT_ENABLE
+/**************************************************************************
+ *
+ * Doing it with shared memory
+ *
+ **************************************************************************/
+
+/*@-mustfreefresh -compdestroy@*/
+static int shm_mainloop(void)
+{
+    int status;
+    if ((status = gps_open(GPSD_SHARED_MEMORY, NULL, &gpsdata)) != 0) {
+	(void)fprintf(stderr,
+		      "%s: shm open failed with status %d.\n",
+		      progname, status);
+	return 1;
+    }
+
+    print_gpx_header();
+    for (;;) {
+	status = gps_read(&gpsdata);
+
+	if (status == -1)
+	    break;
+	if (status > 0)
+	    conditionally_log_fix(&gpsdata);
+    }
+    (void)gps_close(&gpsdata);
+    return 0;
+}
+
+/*@+mustfreefresh +compdestroy@*/
+#endif /* SHM_EXPORT_ENABLE */
 
 /**************************************************************************
  *
@@ -331,13 +370,32 @@ static int socket_mainloop(void)
  *
  **************************************************************************/
 
+struct method_t
+{
+    const char *name;
+    int (*method)(void);
+    const char *description;
+};
+
+static struct method_t methods[] = {
+#if defined(DBUS_EXPORT_ENABLE) && !defined(S_SPLINT_S)
+    {"dbus", dbus_mainloop, "DBUS broadcast"},
+#endif /* defined(DBUS_EXPORT_ENABLE) && !defined(S_SPLINT_S) */
+#ifdef SHM_EXPORT_ENABLE
+    {"shm", shm_mainloop, "shared memory"},
+#endif /* SOCKET_EXPORT_ENABLE */
+#ifdef SOCKET_EXPORT_ENABLE
+    {"sockets", socket_mainloop, "JSON via sockets"},
+#endif /* SOCKET_EXPORT_ENABLE */
+};
+
 static void usage(void)
 {
     fprintf(stderr,
-	    "Usage: %s [-V] [-h] [-d] [-i timeout] [-j casoc] [-f filename] [-m minmove] [server[:port:[device]]]\n",
-	    progname);
-    fprintf(stderr,
-	    "\tdefaults to '%s -i 5 -j 0 localhost:2947'\n", progname);
+	    "Usage: %s [-V] [-h] [-d] [-i timeout] [-f filename] [-m minmove]\n"
+	    "\t[-e exportmethod] [server[:port:[device]]]\n\n"
+	    "defaults to '%s -i 5 -e %s localhost:2947'\n",
+	    progname, progname, (NITEMS(methods) > 0) ? methods[0].name : "(none)");
     exit(1);
 }
 
@@ -346,11 +404,12 @@ int main(int argc, char **argv)
 {
     int ch;
     bool daemonize = false;
+    struct method_t *mp, *method = NULL;
 
     progname = argv[0];
 
     logfile = stdout;
-    while ((ch = getopt(argc, argv, "dD:f:hi:m:V")) != -1) {
+    while ((ch = getopt(argc, argv, "dD:e:f:hi:lm:V")) != -1) {
 	switch (ch) {
 	case 'd':
 	    openlog(basename(progname), LOG_PID | LOG_PERROR, LOG_DAEMON);
@@ -362,6 +421,19 @@ int main(int argc, char **argv)
 	    gps_enable_debug(debug, logfile);
 	    break;
 #endif /* CLIENTDEBUG_ENABLE */
+	case 'e':
+	    for (mp = methods;
+		 mp < methods + NITEMS(methods);
+		 mp++)
+		if (strcmp(mp->name, optarg) == 0)
+		    method = mp;
+	    if (method == NULL) {
+		(void)fprintf(stderr,
+			      "%s: %s is not a known export method.\n",
+			      progname, optarg);
+		exit(1);
+	    }
+	    break;
        case 'f':       /* Output file name. */
             {
                 char    fname[PATH_MAX];
@@ -390,6 +462,12 @@ int main(int argc, char **argv)
 		fprintf(stderr,
 			"WARNING: track timeout is an hour or more!\n");
 	    break;
+	case 'l':
+	    for (method = methods;
+		 method < methods + NITEMS(methods);
+		 method++)
+		(void)printf("%s: %s\n", method->name, method->description);
+	    exit(0);
         case 'm':
 	    minmove = (double )atoi(optarg);
 	    break;
@@ -419,10 +497,8 @@ int main(int argc, char **argv)
     /* initializes the some gpsdata data structure */
     gpsdata.status = STATUS_NO_FIX;
     gpsdata.satellites_used = 0;
-    gpsdata.dop.hdop = NAN;
-    gpsdata.dop.vdop = NAN;
-    gpsdata.dop.pdop = NAN;
     gps_clear_fix(&(gpsdata.fix));
+    gps_clear_dop(&(gpsdata.dop));
 
     /* catch all interesting signals */
     (void)signal(SIGTERM, quit_handler);
@@ -440,16 +516,13 @@ int main(int argc, char **argv)
 
     //syslog (LOG_INFO, "---------- STARTED ----------");
 
-    print_gpx_header();
-
-#ifdef DBUS_ENABLE
-    /* To force socket use in the default way just give a 'localhost' arg */
-    if (optind < argc)
-	return socket_mainloop();
-    else
-	return dbus_mainloop();
-#else
-    return socket_mainloop();
-#endif
+    if (method != NULL) {
+	exit((*method->method)());
+    } else if (NITEMS(methods)) {
+	exit((methods[0].method)());
+    } else {
+	(void)fprintf(stderr, "%s: no export methods.\n", progname);
+	exit(1);
+    }
 }
 /*@+mustfreefresh +globstate@*/
