@@ -71,8 +71,8 @@ static bool italk_initialize(void)
 static void display_itk_navfix(unsigned char *buf, size_t len)
 {
 
-    unsigned int tow, tod, nsec, d, svlist;
-    unsigned short gps_week, flags, cflags, pflags, nsv;
+    unsigned int tow, tod, d, svlist;
+    unsigned short gps_week, nsv;
     unsigned short year, mon, day, hour, min, sec;
     double epx, epy, epz, evx, evy, evz;
     double latitude, longitude;
@@ -82,9 +82,11 @@ static void display_itk_navfix(unsigned char *buf, size_t len)
     if (len != 296)
 	return;
 
-    flags = (ushort) getleu16(buf, 7 + 4);
+#ifdef __UNUSED__
+    flags = (ushort) getleu16(buf, 7 + 4); */
     cflags = (ushort) getleu16(buf, 7 + 6);
     pflags = (ushort) getleu16(buf, 7 + 8);
+#endif /* __UNUSED__ */
 
 #define MAX(a,b) (((a) > (b)) ? (a) : (b))
     nsv = (ushort) MAX(getleu16(buf, 7 + 12), getleu16(buf, 7 + 14));
@@ -93,7 +95,7 @@ static void display_itk_navfix(unsigned char *buf, size_t len)
     hour = (ushort) getleu16(buf, 7 + 66);
     min = (ushort) getleu16(buf, 7 + 68);
     sec = (ushort) getleu16(buf, 7 + 70);
-    nsec = (ushort) getleu32(buf, 7 + 72);
+    //nsec = (ushort) getleu32(buf, 7 + 72);
     year = (ushort) getleu16(buf, 7 + 76);
     mon = (ushort) getleu16(buf, 7 + 78);
     day = (ushort) getleu16(buf, 7 + 80);
