@@ -42,19 +42,19 @@ static bool nmea_initialize(void)
     cookedwin = derwin(devicewin, 3, 80, 0, 0);
     (void)wborder(cookedwin, 0, 0, 0, 0, 0, 0, 0, 0);
     (void)syncok(cookedwin, true);
-    wattrset(cookedwin, A_BOLD);
-    mvwaddstr(cookedwin, 1, 1, "Time: ");
-    mvwaddstr(cookedwin, 1, 31, "Lat: ");
-    mvwaddstr(cookedwin, 1, 55, "Lon: ");
-    mvwaddstr(cookedwin, 2, 34, " Cooked PVT ");
-    wattrset(cookedwin, A_NORMAL);
+    (void)wattrset(cookedwin, A_BOLD);
+    (void)mvwaddstr(cookedwin, 1, 1, "Time: ");
+    (void)mvwaddstr(cookedwin, 1, 32, "Lat: ");
+    (void)mvwaddstr(cookedwin, 1, 55, "Lon: ");
+    (void)mvwaddstr(cookedwin, 2, 34, " Cooked PVT ");
+    (void)wattrset(cookedwin, A_NORMAL);
 
     nmeawin = derwin(devicewin, 3, 80, 3, 0);
     (void)wborder(nmeawin, 0, 0, 0, 0, 0, 0, 0, 0);
     (void)syncok(nmeawin, true);
-    wattrset(nmeawin, A_BOLD);
-    mvwaddstr(nmeawin, 2, 34, " Sentences ");
-    wattrset(nmeawin, A_NORMAL);
+    (void)wattrset(nmeawin, A_BOLD);
+    (void)mvwaddstr(nmeawin, 2, 34, " Sentences ");
+    (void)wattrset(nmeawin, A_NORMAL);
 
     satwin = derwin(devicewin, MAXSATS + 3, 20, 6, 0);
     (void)wborder(satwin, 0, 0, 0, 0, 0, 0, 0, 0), (void)syncok(satwin, true);
@@ -134,7 +134,7 @@ static void cooked_pvt(void)
 	(void)unix_to_iso8601(session.gpsdata.fix.time, scr, sizeof(scr));
     } else
 	(void)snprintf(scr, sizeof(scr), "n/a");
-    (void)mvwprintw(cookedwin, 1, 7, "%-22s", scr);
+    (void)mvwprintw(cookedwin, 1, 7, "%-24s", scr);
 
 
     if (session.gpsdata.fix.mode >= MODE_2D
@@ -145,7 +145,7 @@ static void cooked_pvt(void)
 		       (session.gpsdata.fix.latitude < 0) ? 'S' : 'N');
     } else
 	(void)snprintf(scr, sizeof(scr), "n/a");
-    (void)mvwprintw(cookedwin, 1, 36, "%-17s", scr);
+    (void)mvwprintw(cookedwin, 1, 37, "%-17s", scr);
 
     if (session.gpsdata.fix.mode >= MODE_2D
 	&& isnan(session.gpsdata.fix.longitude) == 0) {
@@ -188,7 +188,7 @@ static void nmea_update(void)
 		*--s_end = '.';
 		*--s_end = '.';
 	    }
-	    mvwaddstr(nmeawin, SENTENCELINE, 1, sentences);
+	    (void)mvwaddstr(nmeawin, SENTENCELINE, 1, sentences);
 	}
 
 	/*
@@ -202,10 +202,10 @@ static void nmea_update(void)
 
 	    tick_interval = now - last_tick;
 	    if (findme != NULL) {
-		mvwchgat(nmeawin, SENTENCELINE, 1, xmax - 13, A_NORMAL, 0,
-			 NULL);
-		mvwchgat(nmeawin, SENTENCELINE, 1 + (findme - sentences),
-			 (int)strlen(fields[0]), A_BOLD, 0, NULL);
+		(void)mvwchgat(nmeawin, SENTENCELINE, 1, xmax - 13, A_NORMAL, 0,
+			       NULL);
+		(void)mvwchgat(nmeawin, SENTENCELINE, 1 + (findme - sentences),
+			       (int)strlen(fields[0]), A_BOLD, 0, NULL);
 	    }
 	}
 	last_tick = now;
@@ -267,9 +267,9 @@ static void nmea_update(void)
 	    getmaxyx(gpgsawin, ymax, xmax);
 	    (void)mvwaddnstr(gpgsawin, 2, 7, scr, xmax - 2 - 7);
 	    if (strlen(scr) >= (size_t) (xmax - 2)) {
-		mvwaddch(gpgsawin, 2, xmax - 2 - 7, (chtype) '.');
-		mvwaddch(gpgsawin, 2, xmax - 3 - 7, (chtype) '.');
-		mvwaddch(gpgsawin, 2, xmax - 4 - 7, (chtype) '.');
+		(void)mvwaddch(gpgsawin, 2, xmax - 2 - 7, (chtype) '.');
+		(void)mvwaddch(gpgsawin, 2, xmax - 3 - 7, (chtype) '.');
+		(void)mvwaddch(gpgsawin, 2, xmax - 4 - 7, (chtype) '.');
 	    }
 	    monitor_fixframe(gpgsawin);
 	    (void)mvwprintw(gpgsawin, 3, 8, "%-5s", fields[16]);
@@ -329,7 +329,7 @@ const struct monitor_object_t nmea_mmt = {
  *
  *****************************************************************************/
 
-#if defined(ALLOW_CONTROLSEND) && defined(ASHTECH_ENABLE)
+#if defined(CONTROLSEND_ENABLE) && defined(ASHTECH_ENABLE)
 static void monitor_nmea_send(const char *fmt, ...)
 {
     char buf[BUFSIZ];
@@ -340,7 +340,7 @@ static void monitor_nmea_send(const char *fmt, ...)
     va_end(ap);
     (void)monitor_control_send((unsigned char *)buf, strlen(buf));
 }
-#endif /* defined(ALLOW_CONTROLSEND) && defined(ASHTECH_ENABLE) */
+#endif /* defined(CONTROLSEND_ENABLE) && defined(ASHTECH_ENABLE) */
 
 /*
  * Yes, it's OK for most of these to be clones of the generic NMEA monitor
@@ -370,7 +370,7 @@ extern const struct gps_type_t ashtech;
 #define ASHTECH_SPEED_9600 5
 #define ASHTECH_SPEED_57600 8
 
-#ifdef ALLOW_CONTROLSEND
+#ifdef CONTROLSEND_ENABLE
 static int ashtech_command(char line[])
 {
     switch (line[0]) {
@@ -418,16 +418,16 @@ static int ashtech_command(char line[])
 
     return COMMAND_UNKNOWN;
 }
-#endif /* ALLOW_CONTROLSEND */
+#endif /* CONTROLSEND_ENABLE */
 
 const struct monitor_object_t ashtech_mmt = {
     .initialize = nmea_initialize,
     .update = nmea_update,
-#ifdef ALLOW_CONTROLSEND
+#ifdef CONTROLSEND_ENABLE
     .command = ashtech_command,
 #else
     .command = NULL,
-#endif /* ALLOW_CONTROLSEND */
+#endif /* CONTROLSEND_ENABLE */
     .wrap = nmea_wrap,
     .min_y = 21,.min_x = 80,
     .driver = &ashtech,
