@@ -294,6 +294,12 @@ static void nextstate(struct gps_packet_t *lexer, unsigned char c)
 	    break;
 	}
 #endif /* RTCM104V3_ENABLE */
+#ifdef PASSTHROUGH_ENABLE
+	if (c == '{') {
+	    lexer->state = JSON_LEADER;
+	    character_pushback(lexer);
+	}
+#endif /* PASSTHROUGH_ENABLE */
 	break;
     case COMMENT_BODY:
 	if (c == '\n')
@@ -830,11 +836,8 @@ static void nextstate(struct gps_packet_t *lexer, unsigned char c)
 	    csum ^= lexer->inbuffer[n];
 	if (csum != c) {
 	    gpsd_report(LOG_IO,
-			"Navcom packet type 0x%hx bad checksum 0x%hx, expecting 0x%hx\n",
+			"Navcom packet type 0x%hhx bad checksum 0x%hhx, expecting 0x%x\n",
 			lexer->inbuffer[3], csum, c);
-	    gpsd_report(LOG_RAW, "Navcom packet dump: %s\n",
-			gpsd_hexdump_wrapper(lexer->inbuffer, lexer->inbuflen,
-					     LOG_RAW));
 	    lexer->state = GROUND_STATE;
 	    break;
 	}
@@ -1187,6 +1190,98 @@ static void nextstate(struct gps_packet_t *lexer, unsigned char c)
 	    lexer->state = GROUND_STATE;
 	break;
 #endif /* RTCM104V2_ENABLE */
+#ifdef PASSTHROUGH_ENABLE
+    case JSON_LEADER:
+	if (c == '{' || c == '[') {
+	    lexer->json_depth++;
+	} else if (c == '}' || c == ']') {
+	    if (--lexer->json_depth == 0)
+		lexer->state = JSON_RECOGNIZED;
+	} else if (isspace(c) || c == ',')
+	    break;
+	else if (c == '"') {
+	    lexer->state = JSON_STRINGLITERAL;
+	    lexer->json_after = JSON_END_ATTRIBUTE;
+	} else {
+	    gpsd_report(LOG_RAW + 2, 
+			"%08ld: missing attribute start after header\n",
+			lexer->char_counter);
+	    lexer->state = GROUND_STATE;
+	}
+	break;
+    case JSON_STRINGLITERAL:
+	if (c == '\\')
+	    lexer->state = JSON_STRING_SOLIDUS;
+	else if (c == '"')
+	    lexer->state = lexer->json_after;
+	break;
+    case JSON_STRING_SOLIDUS:
+	lexer->state = JSON_STRINGLITERAL;
+	break;
+    case JSON_END_ATTRIBUTE:
+	if (isspace(c))
+	    break;
+	else if (c == ':')
+	    lexer->state = JSON_EXPECT_VALUE;
+	else
+	    /* saw something other than value start after colon */
+	    lexer->state = GROUND_STATE;
+	break;
+    case JSON_EXPECT_VALUE:
+	if (isspace(c))
+	    break;
+	else if (c == '"') {
+	    lexer->state = JSON_STRINGLITERAL;
+	    lexer->json_after = JSON_END_VALUE;
+	} else if (c == '{' || c == '[') {
+	    lexer->state = JSON_LEADER;
+	    character_pushback(lexer);
+	} else if (strchr("-0123456789", c) != NULL) {
+	    lexer->state = JSON_NUMBER;
+	} else if (c == 't' || c == 'f' || c == 'n')
+	    /*
+	     * This is a bit more permissive than strictly necessary, as
+	     * GPSD JSON does not include the null token.  Still, it's
+	     * futureproofing.
+	     */
+	    lexer->state = JSON_SPECIAL;
+	else
+	    /* couldn't recognize start of value literal */
+	    lexer->state = GROUND_STATE;
+	break;
+    case JSON_NUMBER:
+	/*
+	 * Will recognize some ill-formed numeric literals.
+	 * Should be OK as we're already three stages deep inside
+	 * JSON recognition; odds that we'll actually see an
+	 * ill-formed literal are quite low. and the worst
+	 * possible result if it happens is our JSON parser will
+	 * quietly chuck out the object.
+	 */
+	if (strchr("1234567890.eE+-", c) == NULL) {
+	    lexer->state = JSON_END_VALUE;
+	    character_pushback(lexer);
+	}
+	break;
+    case JSON_SPECIAL:
+	if (strchr("truefalsnil", c) == NULL) {
+	    lexer->state = JSON_END_VALUE;
+	    character_pushback(lexer);
+	}
+	break;
+    case JSON_END_VALUE:
+	if (isspace(c))
+	    break;
+	else if (c == ',')
+	    lexer->state = JSON_LEADER;
+	else if (c == '}' || c == ']') {
+	    lexer->state = JSON_LEADER;
+	    character_pushback(lexer);
+	} else
+	    /* trailing garbage after JSON value */
+	    lexer->state = GROUND_STATE;
+	break;
+#endif /* PASSTHROUGH_ENABLE */
     }
 /*@ -charint +casebreak @*/
 }
@@ -1200,10 +1295,10 @@ static void packet_accept(struct gps_packet_t *lexer, int packet_type)
 	lexer->outbuflen = packetlen;
 	lexer->outbuffer[packetlen] = '\0';
 	lexer->type = packet_type;
-	gpsd_report(LOG_RAW+1, "Packet type %d accepted %zu = %s\n",
+	if (lexer->debug >= LOG_RAW+1)
+	    gpsd_report(LOG_RAW+1, "Packet type %d accepted %zu = %s\n",
 		    packet_type, packetlen,
-		    gpsd_hexdump_wrapper(lexer->outbuffer, lexer->outbuflen,
-					 LOG_RAW+1));
+			gpsd_hexdump((char *)lexer->outbuffer, lexer->outbuflen));
     } else {
 	gpsd_report(LOG_ERROR, "Rejected too long packet type %d len %zu\n",
 		    packet_type, packetlen);
@@ -1217,11 +1312,11 @@ static void packet_discard(struct gps_packet_t *lexer)
     size_t remaining = lexer->inbuflen - discard;
     lexer->inbufptr = memmove(lexer->inbuffer, lexer->inbufptr, remaining);
     lexer->inbuflen = remaining;
-    gpsd_report(LOG_RAW + 1,
-		"Packet discard of %zu, chars remaining is %zu = %s\n",
-		discard, remaining,
-		gpsd_hexdump_wrapper(lexer->inbuffer, lexer->inbuflen,
-				     LOG_RAW + 1));
+    if (lexer->debug >= LOG_RAW+1)
+	gpsd_report(LOG_RAW + 1,
+		    "Packet discard of %zu, chars remaining is %zu = %s\n",
+		    discard, remaining,
+		    gpsd_hexdump((char *)lexer->inbuffer, lexer->inbuflen));
 }
 
 static void character_discard(struct gps_packet_t *lexer)
@@ -1229,10 +1324,10 @@ static void character_discard(struct gps_packet_t *lexer)
 {
     memmove(lexer->inbuffer, lexer->inbuffer + 1, (size_t)-- lexer->inbuflen);
     lexer->inbufptr = lexer->inbuffer;
-    gpsd_report(LOG_RAW + 1, "Character discarded, buffer %zu chars = %s\n",
-		lexer->inbuflen,
-		gpsd_hexdump_wrapper(lexer->inbuffer, lexer->inbuflen,
-				     LOG_RAW + 1));
+    if (lexer->debug >= LOG_RAW+1)
+	gpsd_report(LOG_RAW + 1, "Character discarded, buffer %zu chars = %s\n",
+		    lexer->inbuflen,
+		    gpsd_hexdump((char *)lexer->inbuffer, lexer->inbuflen));
 }
 
 /* get 0-origin big-endian words relative to start of packet buffer */
@@ -1244,6 +1339,9 @@ void packet_init( /*@out@*/ struct gps_packet_t *lexer)
 {
     lexer->char_counter = 0;
     lexer->retry_counter = 0;
+#ifdef PASSTHROUGH_ENABLE
+    lexer->json_depth = 0;
+#endif /* PASSTHROUGH_ENABLE */
     packet_reset(lexer);
 }
 
@@ -1350,10 +1448,8 @@ void packet_parse(struct gps_packet_t *lexer)
 	    for (n = 0; n < lexer->length - 2; n++)
 		a += (unsigned)lexer->inbuffer[n];
 	    b = (unsigned)getleu16(lexer->inbuffer, lexer->length - 2);
-	    gpsd_report(LOG_IO, "SuperStarII pkt dump: type %u len %u: %s\n",
-			lexer->inbuffer[1], (unsigned int)lexer->length,
-			gpsd_hexdump_wrapper(lexer->inbuffer, lexer->length,
-					     LOG_IO));
+	    gpsd_report(LOG_IO, "SuperStarII pkt dump: type %u len %u\n",
+			lexer->inbuffer[1], (unsigned int)lexer->length);
 	    if (a != b) {
 		gpsd_report(LOG_IO, "REJECT SuperStarII packet type 0x%02x"
 			    "%zd bad checksum 0x%04x, expecting 0x%04x\n",
@@ -1411,9 +1507,10 @@ void packet_parse(struct gps_packet_t *lexer)
 	    if (packetlen < 5) {
 		lexer->state = GROUND_STATE;
 	    } else {
-		unsigned int pkt_id, len;
-		size_t n;
+		unsigned int pkt_id;
 #ifdef GARMIN_ENABLE
+		unsigned int len;
+		size_t n;
 		unsigned int ch, chksum;
 		n = 0;
 		/*@ +charint */
@@ -1447,7 +1544,8 @@ void packet_parse(struct gps_packet_t *lexer)
 		}
 		if (lexer->inbuffer[n++] != DLE)
 		    goto not_garmin;
-		if (lexer->inbuffer[n++] != ETX)
+		/* we used to say n++ here, but scan-build complains */
+		if (lexer->inbuffer[n] != ETX)
 		    goto not_garmin;
 		/*@ +charint */
 		chksum &= 0xff;
@@ -1456,10 +1554,6 @@ void packet_parse(struct gps_packet_t *lexer)
 				"Garmin checksum failed: %02x!=0\n", chksum);
 		    goto not_garmin;
 		}
-		/* Debug
-		 * gpsd_report(LOG_IO, "Garmin n= %#02x\n %s\n", n,
-		 * gpsd_hexdump_wrapper(lexer->inbuffer, packetlen, LOG_IO));
-		 */
 		packet_accept(lexer, GARMIN_PACKET);
 		packet_discard(lexer);
 		break;
@@ -1648,7 +1742,7 @@ void packet_parse(struct gps_packet_t *lexer)
 		packet_accept(lexer, UBX_PACKET);
 	    else {
 		gpsd_report(LOG_IO,
-			    "UBX checksum 0x%02hhx%02hhx over length %hd,"
+			    "UBX checksum 0x%02hhx%02hhx over length %d,"
 			    " expecting 0x%02hhx%02hhx (type 0x%02hhx%02hhx)\n",
 			    ck_a,
 			    ck_b,
@@ -1693,7 +1787,8 @@ void packet_parse(struct gps_packet_t *lexer)
 	    }
 	    if (lexer->inbuffer[n++] != DLE)
 		goto not_evermore;
-	    if (lexer->inbuffer[n++] != ETX)
+	    /* we used to say n++ here, but scan-build complains */
+	    if (lexer->inbuffer[n] != ETX)
 		goto not_evermore;
 	    crc &= 0xff;
 	    if (crc != checksum) {
@@ -1719,21 +1814,20 @@ void packet_parse(struct gps_packet_t *lexer)
 #define getiw(i) ((uint16_t)(((uint16_t)getib((i)+1) << 8) | (uint16_t)getib((i))))
 
 	else if (lexer->state == ITALK_RECOGNIZED) {
-	    volatile uint16_t len, n, csum, xsum, tmpw;
-	    volatile uint32_t tmpdw;
+	    volatile uint16_t len, n, csum, xsum;
 
 	    /* number of words */
 	    len = (uint16_t) (lexer->inbuffer[6] & 0xff);
 
 	    /*@ -type @*/
-	    /* initialize all my registers */
-	    csum = tmpw = tmpdw = 0;
 	    /* expected checksum */
 	    xsum = getiw(7 + 2 * len);
 
+
+	    csum = 0;
 	    for (n = 0; n < len; n++) {
-		tmpw = getiw(7 + 2 * n);
-		tmpdw = (csum + 1) * (tmpw + n);
+		volatile uint16_t tmpw = getiw(7 + 2 * n);
+		volatile uint32_t tmpdw  = (csum + 1) * (tmpw + n);
 		csum ^= (tmpdw & 0xffff) ^ ((tmpdw >> 16) & 0xffff);
 	    }
 	    /*@ +type @*/
@@ -1812,6 +1906,19 @@ void packet_parse(struct gps_packet_t *lexer)
 	    }
 	}
 #endif
+#ifdef PASSTHROUGH_ENABLE
+	else if (lexer->state == JSON_RECOGNIZED) {
+	    size_t packetlen = lexer->inbufptr - lexer->inbuffer;
+	    if (packetlen >= 11)
+		/* {"class": } */
+		packet_accept(lexer, JSON_PACKET);
+	    else
+		packet_accept(lexer, BAD_PACKET);
+	    packet_discard(lexer);
+	    lexer->state = GROUND_STATE;
+	    break;
+	}
+#endif /* PASSTHROUGH_ENABLE */
     }				/* while */
 }
 
@@ -1837,11 +1944,11 @@ ssize_t packet_get(int fd, struct gps_packet_t *lexer)
 	    return -1;
 	}
     } else {
-	gpsd_report(LOG_RAW + 1,
-		    "Read %zd chars to buffer offset %zd (total %zd): %s\n",
-		    recvd, lexer->inbuflen, lexer->inbuflen + recvd,
-		    gpsd_hexdump_wrapper(lexer->inbufptr, (size_t) recvd,
-					 LOG_RAW + 1));
+	if (lexer->debug >= LOG_RAW+1)
+	    gpsd_report(LOG_RAW + 1,
+			"Read %zd chars to buffer offset %zd (total %zd): %s\n",
+			recvd, lexer->inbuflen, lexer->inbuflen + recvd,
+			gpsd_hexdump((char *)lexer->inbufptr, (size_t) recvd));
 	lexer->inbuflen += recvd;
     }
     gpsd_report(LOG_SPIN, "packet_get() fd %d -> %zd (%d)\n",
