@@ -81,7 +81,7 @@ static int fusercount(const char *path)
     int cnt = 0;
 
     if ((procd = opendir("/proc")) == NULL)
-	return false;
+	return -1;
     while ((procentry = readdir(procd)) != NULL) {
 	if (isdigit(procentry->d_name[0])==0)
 	    continue;
@@ -96,8 +96,7 @@ static int fusercount(const char *path)
 	    if (readlink(fdpath, linkpath, sizeof(linkpath)) == -1)
 		continue;
 	    if (strcmp(linkpath, path) == 0) {
-		(void)closedir(procd);
-		return true;
+		++cnt;
 	    }
 	}
 	(void)closedir(fdd);
